UntypedMem

Trait UntypedMem 

pub trait UntypedMem {
    // Required methods
    exec fn reader(&self) -> VmReader<'_, Infallible>;
    exec fn writer(&self) -> VmWriter<'_, Infallible>;
}
A physical memory range that is untyped.

Untyped frames or segments can be safely read and written by the kernel or the user.

TODO: Perhaps we also need to define this?

Required Methods

exec fn reader(&self) -> VmReader<'_, Infallible>

Borrows a reader that can read the untyped memory.

exec fn writer(&self) -> VmWriter<'_, Infallible>

Borrows a writer that can write the untyped memory.

Implementors