pub trait UntypedMem {
// Required methods
exec fn reader(&self) -> VmReader<'_, Infallible>;
exec fn writer(&self) -> VmWriter<'_, Infallible>;
}Expand description
A physical memory range that is untyped.
Untyped frames or segments can be safely read and written by the kernel or the user.
TODO: Perhaps we also need to define this?
Required Methods
Sourceexec fn reader(&self) -> VmReader<'_, Infallible>
exec fn reader(&self) -> VmReader<'_, Infallible>
Borrows a reader that can read the untyped memory.
Sourceexec fn writer(&self) -> VmWriter<'_, Infallible>
exec fn writer(&self) -> VmWriter<'_, Infallible>
Borrows a writer that can write the untyped memory.